@@ -73,7 +73,7 @@ void ScriptCompiler::fastBranch(ScriptInterp *interp)
 
 	while(maxstep-- && NULL != (line = interp->getLine()))
 	{
-		m = line->method;
+		m = line->scr.method;
 		if(line->loop == 0xffff)
 		{
 			if(interp->getTrace())
@@ -985,7 +985,7 @@ repname1:
 		line->next = NULL;
 		line->args = (const char **)alloc(sizeof(char *) * argc);
 		line->argc = --argc;
-		line->method = handler;
+		line->scr.method = handler;
 		line->cmd = command;
 		line->loop = 0;
 		if(cmds->isInitial(line->cmd))
