@@ -144,13 +144,13 @@ const char *ScriptInterp::getExternal(const char *opt)
 	}
 	else if(!stricmp(opt, "script.name"))
 		return frame[stack].script->name;
-	else if(!stricmp(opt, "script.stack") || !strnicmp(opt, "script.stack.val", 16))
+	else if(!stricmp(opt, "script.stack"))
 	{
 		cp = getTemp();
 		snprintf(cp, symsize, "%d", stack);
 		return cp;
 	}
-	else if(!stricmp(opt, "script.base") || !strnicmp(opt, "script.base.val", 15))
+	else if(!stricmp(opt, "script.base"))
 	{
 		cp = getTemp();
 		snprintf(cp, symsize, "%d", frame[stack].base);
@@ -181,21 +181,32 @@ Script::Name *ScriptInterp::getScript(const char *name)
 	return scr;
 }
 
+void ScriptInterp::release(void)
+{
+	if(lock)
+	{
+		lock->leaveMutex();
+		lock = NULL;
+	}
+}
+
 ScriptSymbols *ScriptInterp::getSymbols(const char *id)
 {
-	if(strchr(id, '.') && session != this)
+	Thread *th = Thread::get();
+
+	if(th && th == (Thread *)thread)
+		goto top;
+	else if(strchr(id, '.') && session != this)
 	{
 		if(lock)
 			lock->leaveMutex();
 		session->enterMutex();
 		lock = dynamic_cast<Mutex *>(session);
 	}
-	else if(lock)
-	{
-		lock->leaveMutex();
-		lock = NULL;
-	}
-		
+	else
+		release();
+
+top:		
 	if(strchr(id, '.'))
 		return dynamic_cast<ScriptSymbols*>(session);
 	if(!frame[stack].local)
@@ -644,15 +655,9 @@ void ScriptInterp::initRuntime(Name *scr)
 
 bool ScriptInterp::attach(ScriptCommand *cmdref, const char *scrname)
 {
-	ScriptImage::InitialList *ilist;
-	ScriptBinder *mod = ScriptBinder::first;
-	Name *scr, *init;
-	stack = 0;
-	cmd = cmdref;
-	exiting = initialized = false;
-	session = this;
-	thread = NULL;
+	Name *scr;
 
+	cmd = cmdref;
 	enterMutex();
 
 	purge();
@@ -667,7 +672,6 @@ bool ScriptInterp::attach(ScriptCommand *cmdref, const char *scrname)
 		return false;
 	}
 
-	frame[stack].local = NULL;
 	scr = getScript(scrname);
 	if(!scr || scr->access != scrPUBLIC)
 	{
@@ -679,6 +683,25 @@ bool ScriptInterp::attach(ScriptCommand *cmdref, const char *scrname)
 
 	++image->refcount;
 	cmd->leaveMutex();
+	attach(cmd, image, scr);
+	return true;
+}
+
+void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
+{
+	const char *scrname = scr->name;
+	ScriptImage::InitialList *ilist;
+	ScriptBinder *mod = ScriptBinder::first;
+	Name *init;
+	stack = 0;
+	cmd = cmdref;
+	exiting = initialized = false;
+	session = this;
+	thread = NULL;
+	
+	image = img;
+
+	frame[stack].local = NULL;
 
 	for(tempidx = 0; tempidx < SCRIPT_TEMP_SPACE; ++tempidx)
 		temps[tempidx] = (char *)alloc(symsize + 1);
@@ -715,7 +738,6 @@ bool ScriptInterp::attach(ScriptCommand *cmdref, const char *scrname)
 	initRuntime(scr);
 	image->fastBranch(this);
 	leaveMutex();
-	return true;
 }
 
 void ScriptInterp::detach(void)
@@ -766,7 +788,6 @@ void ScriptInterp::detach(void)
 
 bool ScriptInterp::step(void)
 {
-//	unsigned long mask, cmask;
 	bool rtn = false;
 	Line *next, *line;
 	unsigned count = autoStepping;
@@ -779,32 +800,13 @@ bool ScriptInterp::step(void)
 	if(!frame[stack].line)
 		goto exit;
 
-	// auto return code
-
-/*
-	cmask = script[stack].line->cmask;
-	if(cmask)
-	{
-		if((cmask & script[stack].mask) != cmask)
-		{
-			skip = true;
-			advance();
-			goto retry;
-		}
-	}
-*/
-
 trans:
 	updated = false;
 	frame[stack].index = 0;
 	line = getLine();
 	next = line->next;
-	rtn = execute(line->method);
-	if(lock)
-	{
-		lock->leaveMutex();
-		lock = NULL;
-	}
+	rtn = execute(line->scr.method);
+	release();
 
 	if(!rtn || !frame[stack].line)
 		goto exit;
@@ -835,13 +837,12 @@ exit:
 		rtn = false;
 	}
 	else if(!rtn && thread)
-		startThread();
-
-	if(lock)
 	{
-		lock->leaveMutex();
-		lock = NULL;
+		release();
+		startThread();
 	}
+	else
+		release();
 
 	leaveMutex();
 
