@@ -55,7 +55,7 @@ bool ScriptMethods::scrIf(void)
 		if(frame[stack].index < frame[stack].line->argc)
 			return scrGoto();
 		skip();
-		if(frame[stack].line->method == (Method)&ScriptMethods::scrThen)
+		if(frame[stack].line->scr.method == (Method)&ScriptMethods::scrThen)
 			skip();
 		return true;
 	}
@@ -120,14 +120,14 @@ bool ScriptMethods::scrThen(void)
         {
                 skip();
 
-                if(line->method == (Method)&ScriptMethods::scrThen)
+                if(line->scr.method == (Method)&ScriptMethods::scrThen)
                         ++level;
-                else if(line->method == (Method)&ScriptMethods::scrElse)
+                else if(line->scr.method == (Method)&ScriptMethods::scrElse)
                 {   
                         if(!level)
                                 return true;
                 }
-                else if(line->method == (Method)&ScriptMethods::scrEndif)
+                else if(line->scr.method == (Method)&ScriptMethods::scrEndif)
                 {
                         if(!level)
                                 return true;
@@ -148,9 +148,9 @@ bool ScriptMethods::scrElse(void)
         {
 		skip();
 
-                if(line->method == (Method)&ScriptMethods::scrThen)
+                if(line->scr.method == (Method)&ScriptMethods::scrThen)
                         ++level;
-                else if(line->method == (Method)&ScriptMethods::scrEndif)
+                else if(line->scr.method == (Method)&ScriptMethods::scrEndif)
                 {
                         if(!level)
                                 return true;
@@ -1640,7 +1640,7 @@ bool ScriptMethods::scrCase(void)
 			skip();
 			while(frame[stack].line)
 			{
-				if(frame[stack].line->method == (Method)&ScriptMethods::scrCase)
+				if(frame[stack].line->scr.method == (Method)&ScriptMethods::scrCase)
 					skip();
 				else
 					return true;
@@ -1657,10 +1657,10 @@ bool ScriptMethods::scrCase(void)
 		if(line->loop == loop)
 			return true;
 
-		if(line->method == (Method)&ScriptMethods::scrCase && !frame[stack].caseflag)
+		if(line->scr.method == (Method)&ScriptMethods::scrCase && !frame[stack].caseflag)
 			return true;
 
-		if(line->method == (Method)&ScriptMethods::scrEndcase)
+		if(line->scr.method == (Method)&ScriptMethods::scrEndcase)
 			return true;
 
 		skip();
@@ -1690,7 +1690,7 @@ bool ScriptMethods::scrOffset(void)
 	}
 
 	line = frame[stack - 1].line;
-	method = line->method;
+	method = line->scr.method;
 	
 	if(method != (Method)&ScriptMethods::scrForeach &&
 	   method != (Method)&ScriptMethods::scrFor)
@@ -1709,7 +1709,7 @@ bool ScriptMethods::scrOffset(void)
 	else
 		frame[stack].index += (unsigned short)offset;
 	updated = false;
-	return execute(frame[stack].line->method);
+	return execute(frame[stack].line->scr.method);
 }
 
 bool ScriptMethods::scrRepeat(void)
@@ -2007,7 +2007,7 @@ bool ScriptMethods::scrLoop(void)
 
 	--stack;
 	updated = false;
-	return execute(frame[stack].line->method);
+	return execute(frame[stack].line->scr.method);
 }
 
 bool ScriptMethods::scrContinue(void)
