@@ -55,6 +55,7 @@
 #define	SCRIPT_MAX_ARGS	250
 #define	SCRIPT_TEMP_SPACE 16
 #define	SCRIPT_STACK_SIZE 32
+#define	SCRIPT_ROUTE_SLOTS 16
 
 namespace ost {
 
@@ -77,6 +78,7 @@ class __EXPORT Script
 {
 protected:
 	class __EXPORT Line;
+	class __EXPORT Name;
 
 
 public:
@@ -146,7 +148,11 @@ protected:
 	{
 	public:
 		Line *next;
-		Method method;
+		union
+		{
+			Method method;
+			Name *name;
+		}	scr;
 		const char *cmd, **args;
 		unsigned long cmask, mask;
 		unsigned short loop, line, lnum;
@@ -168,7 +174,7 @@ public:
 	public:
 		Name *next;
 		Event *events;
-		Line *first;
+		Line *first, *select;
 		Line *trap[TRAP_BITS];
 		unsigned long mask;
 		const char *name, *filename;
@@ -322,7 +328,7 @@ private:
 	int keyword_count;
 	int trap_count;
 	unsigned long imask;
-	bool copied;
+	bool ripple;
 	unsigned dbcount;
 	void *dbc;
 
@@ -726,6 +732,24 @@ public:
 	const char *chkSession(Line *line, ScriptImage *img);
 };
 
+/**
+ * A linkable list of objects that can be destroyed when a script image
+ * is removed from memory.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short Object list in image.
+ */
+class __EXPORT ScriptObject : public Script
+{
+private:
+	friend class __EXPORT ScriptImage;
+	ScriptObject *next;
+
+protected:
+	ScriptObject(ScriptImage *image);
+	virtual ~ScriptObject();
+};
+
 /**
  * A derivable class to hold compiled script images for active processes.
  * This includes the script image compiler itself.  Typically, a script is
@@ -738,10 +762,17 @@ public:
 class __EXPORT ScriptImage : public Keydata, public Script, public Assoc
 {
 protected:
+	friend class __EXPORT ScriptObject;
+
 	ScriptCommand *cmds;
 	unsigned refcount;
 	Name *index[SCRIPT_INDEX_SIZE + 1], *current;
+	Line *select, *selecting, *registration;
+	Line *advertising[SCRIPT_ROUTE_SLOTS];
 	Mutex duplock;
+	ScriptObject *objects;
+	static unsigned long serial;
+	unsigned long instance;
 	
 	class	__EXPORT InitialList : public Script::Initial
 	{
@@ -780,6 +811,58 @@ public:
 	inline Name *getCurrent(void)
 		{return current;};
 
+	/**
+	 * Add a select record to the currently compiled script.
+	 *
+	 * @param line statement to add to list.
+	 */
+	void addSelect(Line *line);
+
+	/**
+	 * Add a registration record to the compiled script.
+	 *
+	 * @param line statement to add to list.
+	 */
+	void addRegistration(Line *line);
+
+	/**
+	 * Add an advertised route in a priority slot.
+	 *
+	 * @param line statement to add to list.
+	 * @param route add to.
+	 */
+	void addRoute(Line *line, unsigned pri);
+
+	/**
+	 * Get the selection list from the image.
+	 *
+	 * @return selection list.
+	 */
+	inline Line *getSelect(void)
+		{return select;};
+
+	/**
+	 * Get the registration list from the image.
+	 *
+	 * @return registration list.
+	 */
+	inline Line *getRegistration(void)
+		{return registration;};
+
+	/**
+	 * Get an advertised priority record from the image.
+	 *
+	 * @return priority list.
+	 */
+	inline Line *getRoute(unsigned pri)
+		{return advertising[pri];};
+
+	/**
+	 * Get the session instance of the image.
+	 */
+	inline unsigned long getInstance(void)
+		{return instance;};
+
 protected:
 	/**
 	 * Construct a new working image.  This must be derived to an
@@ -790,6 +873,11 @@ protected:
 	 */
 	ScriptImage(ScriptCommand *cmdset, const char *symset);
 
+	/**
+	 * Destruct the ScriptImage itself by removing linked objects.
+	 */
+	~ScriptImage();
+
 	/**
 	 * Purge and reload the script image workspace.
 	 */
@@ -1173,6 +1261,12 @@ public:
 	bool step(void);
 	bool attach(ScriptCommand *cmd, const char *scrname);
 	void detach(void);
+	void attach(ScriptCommand *cmd, ScriptImage *img, Name *scr);
+
+	/**
+	 * Release any aquired lock...
+	 */
+	void release(void);
 	
        /**
          * Signals are used during "delayed" execution steps when a    
@@ -1304,6 +1398,14 @@ protected:
 	inline bool addSymbol(const char *id, char *buffer, unsigned short max)
 		{return interp->getSymbol(id, buffer, max);};
 
+	void block(void);
+
+	void unblock(void);
+
+	void lock(void);
+
+	void release(void);
+
 public:
 	inline size_t getStack(void)
 		{return stacksize;};
